pub(crate) struct Covariates {
    pub(crate) constant: f64,
    pub(crate) diabetes_factor: f64,
    pub(crate) smoker_factor: f64,
    pub(crate) htn_meds_factor: f64,
    pub(crate) cholesterol_meds_factor: f64,
    pub(crate) age_adjustment_factor: f64,
    pub(crate) age_squared_factor: f64,
    pub(crate) cholesterol_base_multiplier: f64,
    pub(crate) total_cholesterol_diff_factor: f64,
    pub(crate) hdl_cholesterol_diff_factor: f64,
    pub(crate) systolic_bp_min_factor: f64,
    pub(crate) systolic_bp_max_factor: f64,
    pub(crate) egfr_max_factor: f64,
    pub(crate) egfr_min_factor: f64,
    pub(crate) htn_meds_systolic_bp_max_factor: f64,
    pub(crate) cholesterol_meds_cholesterol_diff_factor: f64,
    pub(crate) age_adjustment_cholesterol_diff_factor: f64,
    pub(crate) age_adjustment_hdl_cholesterol_diff_factor: f64,
    pub(crate) age_adjustment_systolic_bp_max_factor: f64,
    pub(crate) age_min_egfr_factor: f64,
    pub(crate) diabetes_age_factor: f64,
    pub(crate) smoker_age_factor: f64,
    pub(crate) bmi_min_factor: f64,
    pub(crate) bmi_max_factor: f64,
    pub(crate) age_bmi_max_factor: f64,
}

impl Covariates {
    pub(crate) fn female_10_yr_ascvd() -> Covariates {
        Covariates {
            constant: -3.819975,
            diabetes_factor: 0.8348585,
            smoker_factor: 0.4831078,
            htn_meds_factor: 0.2265309,
            cholesterol_meds_factor: -0.0592374,
            age_adjustment_factor: 0.719883,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.1176967,
            hdl_cholesterol_diff_factor: -0.151185,
            systolic_bp_min_factor: -0.0835358,
            systolic_bp_max_factor: 0.3592852,
            egfr_min_factor: 0.4864619,
            egfr_max_factor: 0.0397779,
            htn_meds_systolic_bp_max_factor: -0.0395762,
            cholesterol_meds_cholesterol_diff_factor: 0.0844423,
            age_adjustment_cholesterol_diff_factor: -0.0567839,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0325692,
            age_adjustment_systolic_bp_max_factor: -0.1035985,
            diabetes_age_factor: -0.2417542,
            smoker_age_factor: -0.0791142,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1671492,
            age_squared_factor: 0.0,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn male_10_yr_ascvd() -> Covariates {
        Covariates {
            constant: -3.500655,
            diabetes_factor: 0.7189597,
            smoker_factor: 0.3956973,
            htn_meds_factor: 0.2036522,
            cholesterol_meds_factor: -0.0865581,
            age_adjustment_factor: 0.7099847,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.1658663,
            hdl_cholesterol_diff_factor: -0.1144285,
            systolic_bp_min_factor: -0.2837212,
            systolic_bp_max_factor: 0.3239977,
            egfr_min_factor: 0.3690075,
            egfr_max_factor: 0.0203619,
            htn_meds_systolic_bp_max_factor: -0.0322916,
            cholesterol_meds_cholesterol_diff_factor: 0.114563,
            age_adjustment_cholesterol_diff_factor: -0.0300005,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0232747,
            age_adjustment_systolic_bp_max_factor: -0.0927024,
            diabetes_age_factor: -0.2018525,
            smoker_age_factor: -0.0970527,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1217081,
            age_squared_factor: 0.0,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn female_30_yr_ascvd() -> Covariates {
        Covariates {
            constant: -1.974074,
            diabetes_factor: 0.6296707,
            smoker_factor: 0.268292,
            htn_meds_factor: 0.1875292,
            cholesterol_meds_factor: 0.0152476,
            age_adjustment_factor: 0.4669202,
            age_squared_factor: -0.0893118,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.1256901,
            hdl_cholesterol_diff_factor: -0.1542255,
            systolic_bp_min_factor: -0.0018093,
            systolic_bp_max_factor: 0.322949,
            egfr_min_factor: 0.100106,
            egfr_max_factor: 0.0499663,
            htn_meds_systolic_bp_max_factor: -0.0276123,
            cholesterol_meds_cholesterol_diff_factor: 0.0736147,
            age_adjustment_cholesterol_diff_factor: -0.0521962,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0316918,
            age_adjustment_systolic_bp_max_factor: -0.1046101,
            diabetes_age_factor: -0.2727793,
            smoker_age_factor: -0.1530907,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1299149,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn male_30_yr_ascvd() -> Covariates {
        Covariates {
            constant: -1.736444,
            diabetes_factor: 0.4790257,
            smoker_factor: 0.1782635,
            htn_meds_factor: 0.1421182,
            cholesterol_meds_factor: 0.0135996,
            age_adjustment_factor: 0.3994099,
            age_squared_factor: -0.0937484,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.1744643,
            hdl_cholesterol_diff_factor: -0.120203,
            systolic_bp_min_factor: -0.0665117,
            systolic_bp_max_factor: 0.2753037,
            egfr_min_factor: -0.0218789,
            egfr_max_factor: 0.0602553,
            htn_meds_systolic_bp_max_factor: -0.0218265,
            cholesterol_meds_cholesterol_diff_factor: 0.1013148,
            age_adjustment_cholesterol_diff_factor: -0.0312619,
            age_adjustment_hdl_cholesterol_diff_factor: 0.020673,
            age_adjustment_systolic_bp_max_factor: -0.0920935,
            diabetes_age_factor: -0.2159947,
            smoker_age_factor: -0.1548811,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.0712547,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn female_10_yr_cvd() -> Covariates {
        Covariates {
            constant: -3.307728,
            diabetes_factor: 0.8667604,
            smoker_factor: 0.5360739,
            htn_meds_factor: 0.3151672,
            cholesterol_meds_factor: -0.1477655,
            age_adjustment_factor: 0.7939329,
            age_squared_factor: 0.0,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.0305239,
            hdl_cholesterol_diff_factor: -0.1606857,
            systolic_bp_min_factor: -0.2394003,
            systolic_bp_max_factor: 0.3600781,
            egfr_min_factor: 0.6045917,
            egfr_max_factor: 0.0433769,
            htn_meds_systolic_bp_max_factor: -0.0663612,
            cholesterol_meds_cholesterol_diff_factor: 0.1197879,
            age_adjustment_cholesterol_diff_factor: -0.0819715,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0306769,
            age_adjustment_systolic_bp_max_factor: -0.0946348,
            diabetes_age_factor: -0.27057,
            smoker_age_factor: -0.078715,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1637806,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn male_10_yr_cvd() -> Covariates {
        Covariates {
            constant: -3.031168,
            diabetes_factor: 0.7692857,
            smoker_factor: 0.4386871,
            htn_meds_factor: 0.288879,
            cholesterol_meds_factor: -0.1337349,
            age_adjustment_factor: 0.7688528,
            age_squared_factor: 0.0,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.0736174,
            hdl_cholesterol_diff_factor: -0.0954431,
            systolic_bp_min_factor: -0.4347345,
            systolic_bp_max_factor: 0.3362658,
            egfr_min_factor: 0.5378979,
            egfr_max_factor: 0.0164827,
            htn_meds_systolic_bp_max_factor: -0.0475924,
            cholesterol_meds_cholesterol_diff_factor: 0.150273,
            age_adjustment_cholesterol_diff_factor: -0.0517874,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0191169,
            age_adjustment_systolic_bp_max_factor: -0.1049477,
            diabetes_age_factor: -0.2251948,
            smoker_age_factor: -0.0895067,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1543702,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn female_30_yr_cvd() -> Covariates {
        Covariates {
            constant: -1.318827,
            diabetes_factor: 0.6793894,
            smoker_factor: 0.3196112,
            htn_meds_factor: 0.2894,
            cholesterol_meds_factor: -0.075688,
            age_adjustment_factor: 0.5503079,
            age_squared_factor: -0.0928369,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.0409794,
            hdl_cholesterol_diff_factor: -0.1663306,
            systolic_bp_min_factor: -0.1628654,
            systolic_bp_max_factor: 0.3299505,
            egfr_min_factor: 0.1857101,
            egfr_max_factor: 0.0553528,
            htn_meds_systolic_bp_max_factor: -0.056367,
            cholesterol_meds_cholesterol_diff_factor: 0.1071019,
            age_adjustment_cholesterol_diff_factor: -0.0751438,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0301786,
            age_adjustment_systolic_bp_max_factor: -0.0998776,
            diabetes_age_factor: -0.3206166,
            smoker_age_factor: -0.1607862,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1450788,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }
    pub(crate) fn male_30_yr_cvd() -> Covariates {
        Covariates {
            constant: -1.148204,
            diabetes_factor: 0.5331276,
            smoker_factor: 0.2141914,
            htn_meds_factor: 0.232714,
            cholesterol_meds_factor: -0.0272112,
            age_adjustment_factor: 0.4627309,
            age_squared_factor: -0.0984281,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.0836088,
            hdl_cholesterol_diff_factor: -0.1029824,
            systolic_bp_min_factor: -0.2140352,
            systolic_bp_max_factor: 0.2904325,
            egfr_min_factor: 0.1155556,
            egfr_max_factor: 0.0603775,
            htn_meds_systolic_bp_max_factor: -0.0384488,
            cholesterol_meds_cholesterol_diff_factor: 0.134192,
            age_adjustment_cholesterol_diff_factor: -0.0511759,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0165865,
            age_adjustment_systolic_bp_max_factor: -0.1101437,
            diabetes_age_factor: -0.2585943,
            smoker_age_factor: -0.1566406,
            bmi_min_factor: 0.0,
            age_min_egfr_factor: -0.1166776,
            bmi_max_factor: 0.0,
            age_bmi_max_factor: 0.0,
        }
    }

    pub(crate) fn female_10_yr_hf() -> Covariates {
        Covariates {
            constant: -4.310409,
            diabetes_factor: 1.0,
            smoker_factor: 0.583916,
            htn_meds_factor: 0.3534442,
            cholesterol_meds_factor: 0.0,
            age_adjustment_factor: 0.8998235,
            age_squared_factor: 0.0,
            cholesterol_base_multiplier: 0.02586,
            total_cholesterol_diff_factor: 0.0,
            hdl_cholesterol_diff_factor: 0.0,
            systolic_bp_min_factor: -0.4559771,
            systolic_bp_max_factor: 0.3576505,
            egfr_min_factor: 0.7451638,
            egfr_max_factor: 0.0557087,
            htn_meds_systolic_bp_max_factor: -0.0981511,
            cholesterol_meds_cholesterol_diff_factor: 0.0,
            age_adjustment_cholesterol_diff_factor: 0.0,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0,
            age_adjustment_systolic_bp_max_factor: -0.0946663,
            diabetes_age_factor: -0.3581041,
            smoker_age_factor: -0.1159453,
            age_min_egfr_factor: -0.1884289,
            bmi_min_factor: -0.0072294,
            bmi_max_factor: 0.2997706,
            age_bmi_max_factor: -0.003878,
        }
    }

    pub(crate) fn male_10_yr_hf() -> Covariates {
        Covariates {
            constant: -3.946391,       //
            diabetes_factor: 0.923776, //
            smoker_factor: 0.5023736,  //
            htn_meds_factor: 0.2980922,
            cholesterol_meds_factor: 0.0,
            age_adjustment_factor: 0.8972642, //
            age_squared_factor: 0.0,
            cholesterol_base_multiplier: 0.0,
            total_cholesterol_diff_factor: 0.0,
            hdl_cholesterol_diff_factor: 0.0,
            systolic_bp_min_factor: -0.6811466, //
            systolic_bp_max_factor: 0.3634461,  //
            egfr_min_factor: 0.6926917,
            egfr_max_factor: 0.0251827,
            htn_meds_systolic_bp_max_factor: -0.0497731,
            cholesterol_meds_cholesterol_diff_factor: 0.0,
            age_adjustment_cholesterol_diff_factor: 0.0,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0,
            age_adjustment_systolic_bp_max_factor: -0.1289201,
            diabetes_age_factor: -0.3040924,
            smoker_age_factor: -0.1401688,
            age_min_egfr_factor: -0.1797778,
            bmi_min_factor: -0.0485841,
            bmi_max_factor: 0.3726929,
            age_bmi_max_factor: 0.0068126,
        }
    }

    pub(crate) fn female_30_yr_hf() -> Covariates {
        Covariates {
            constant: -2.205379,
            diabetes_factor: 0.8330787,
            smoker_factor: 0.3438651,
            htn_meds_factor: 0.333921,
            cholesterol_meds_factor: 0.0,
            age_adjustment_factor: 0.6254374,
            cholesterol_base_multiplier: 0.0,
            total_cholesterol_diff_factor: 0.0,
            hdl_cholesterol_diff_factor: 0.0,
            systolic_bp_min_factor: -0.3919241,
            systolic_bp_max_factor: 0.3142295,
            egfr_min_factor: 0.2981642,
            egfr_max_factor: 0.0667159,
            htn_meds_systolic_bp_max_factor: -0.0893177,
            cholesterol_meds_cholesterol_diff_factor: 0.0,
            age_adjustment_cholesterol_diff_factor: 0.0,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0,
            age_adjustment_systolic_bp_max_factor: -0.0974299,
            diabetes_age_factor: -0.404855,
            smoker_age_factor: -0.1982991,
            bmi_min_factor: 0.0594874,
            age_min_egfr_factor: -0.1564215,
            age_squared_factor: -0.0983038,
            bmi_max_factor: 0.2525536,
            age_bmi_max_factor: -0.0035619,
        }
    }

    pub(crate) fn male_30_yr_hf() -> Covariates {
        Covariates {
            constant: -1.95751,
            diabetes_factor: 0.6840338,
            smoker_factor: 0.2656273,
            htn_meds_factor: 0.2583631,
            cholesterol_meds_factor: 0.0,
            age_adjustment_factor: 0.5681541,
            cholesterol_base_multiplier: 0.0,
            total_cholesterol_diff_factor: 0.0,
            hdl_cholesterol_diff_factor: 0.0,
            systolic_bp_min_factor: -0.4761564,
            systolic_bp_max_factor: 0.30324,
            egfr_min_factor: 0.2541805,
            egfr_max_factor: 0.0638923,
            htn_meds_systolic_bp_max_factor: -0.0391938,
            cholesterol_meds_cholesterol_diff_factor: 0.0,
            age_adjustment_cholesterol_diff_factor: 0.0,
            age_adjustment_hdl_cholesterol_diff_factor: 0.0,
            age_adjustment_systolic_bp_max_factor: -0.1269124,
            diabetes_age_factor: -0.3273572,
            smoker_age_factor: -0.2043019,
            bmi_min_factor: 0.0833107,
            age_min_egfr_factor: -0.1342618,
            age_squared_factor: -0.1048388,
            bmi_max_factor: 0.26999,
            age_bmi_max_factor: -0.0182831,
        }
    }
}
